<?php 
require_once("icwfData.inc.php");
require_once("FormValidation.inc.php");

class EventForm implements icwfData {
  private static $noExport = array();
  private static $notInArray = array("validation");
  private $validation;
  
  private $event_id;
  private $eventForm;

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  private function initialize() {
    $this->event_id = null;
    $this->eventForm = array();
  }
  
  public function __construct(FormValidation $validation=null) {
    $this->initialize();
    $this->validation = $validation;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // get values
  public function __get($name) {
    if($name == "id") return $_SESSION['event']->event_id;
    if (array_key_exists($name, get_class_vars(get_class())) && !in_array($name, self::$noExport))
      return $this->$name;
      
    return null;
  }
  
  public function getIDName() {
    return "event_id";
  }
  
  public function toArray() {
    $array = array();
    foreach ($eventForm as $groupKey => $group)
      $array[$groupKey] = $group->toArray();

    return $array;
  }
  
  public function getPostBackData() {
    $postBackArray = array();
    foreach ($this->eventForm as $optionGroupId => $optionGroup) {
      $tmp = $optionGroup->getPostBackData();
      foreach ($tmp as $key => $value)
        $postBackArray[preg_replace('~^([^\[]+)(.*)$~', "$1[{$optionGroupId}]$2", $key)] = $value; 
    }
    
    return $postBackArray;
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////////
  // set values
  public function setEventId($eventId) {
    $this->event_id = $eventId;
  }

  public function setValidation(FormValidation $validation) {
    $this->validation = $validation;
  }
  
  public function removeGroup($groupIdx) {
    if(isset($this->eventForm[$groupIdx]))
      unset($this->eventForm[$groupIdx]);
  }
  
  public function fromArray($array) {
    foreach ($this->eventForm as &$optionGroup) {
      if(!isset($array['event_option_group_id']) || 
         !in_array($optionGroup->event_option_group_id, $array['event_option_group_id'])) {
        $optionGroup->deleteGroup(true);
      }
    }
    if(isset($array['group_name'])) {
      foreach ($array['group_name'] as $groupIdx => $groupValue) {
        if($array['event_option_group_id'][$groupIdx]) {
          $this->eventForm[$array['event_option_group_id'][$groupIdx]]->fromPOSTArray($array, $groupIdx);
          $this->eventForm[$array['event_option_group_id'][$groupIdx]]->setEventId($this->event_id);
        }
        else {
          $newGroup = new EventOptionsGroup();
          $newGroup->fromPOSTArray($array, $groupIdx);
          $newGroup->setEventId($this->event_id);
          $this->eventForm[] = $newGroup;
        }
      }
    }
    
    return true;
    //return $this->validation->validate($array);
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - read
  public function readData(DbConnection $DB, $conditions="") {
    /*
    if(is_array($conditions)) {
      $whereConditions = array();
      foreach ($conditions as $key => $value)
        if(array_key_exists($key, get_class_vars(get_class())))
          $whereConditions[] = "$key=$value";
      $conditions =  implode(" AND ", $whereConditions);
    }
    */
    
    if(!$this->event_id)
      return array(1, _("No event selected."));
      
    $result = $DB->query("SELECT event_option_group_id
                          FROM event_option_groups eog
                          WHERE event_id='{$this->event_id}'
                          ORDER BY event_option_group_id;");
    if(!$DB->errno() && $DB->num_rows($result)>0) {
      $this->eventForm = array();
      while ($groupId = $DB->fetch_array($result)) {
        $eventGroup = new EventOptionsGroup();
        $eventGroup->readData($DB, array("event_option_group_id"=>$groupId['event_option_group_id']));
        $this->eventForm[$groupId['event_option_group_id']] = $eventGroup;
      }
      
      return array(0, "");
    }
    else
      return array($DB->errno(), $DB->error());
  }
  
  static public function readList(DbConnection $DB) {
    return array();
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - write
  public function writeData(DbConnection $DB) {
    foreach ($this->eventForm as &$optionGroup) {
      $optionGroup->writeData($DB);
    }

    if (!$DB->errno()) {
      KDbLog::writeLog($DB, "Form for event '{$this->event_id}' created / changed.");
      return array(0, "");
    }
    else 
      return array($DB->errno(), $DB->error());
  }

  static public function deleteData(DbConnection $DB, $id) {
    //todo ...
  }

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - misc
  static public function createTable(DbConnection $DB) {
    //Nothing to do
  }  
}
?>