<?php
require_once("cwfUI.inc.php");

class KDbStatisticsUI extends cwfUI {
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  public function __construct() {
    parent::__construct();
    $this->initialize();
  }
  
  protected function initialize() {
    parent::initialize();
    $this->title = _("Administration");
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // security
  static public function isAllowedAction($action) {
    return in_array($action, array("setActive"));
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // handle data
  public function getPostBackXML(DbConnection $DB, $action) {
    switch ($action) {
      case "setActive":
        $xml = "  <replaceHTMLElement id=\"table#activeEvents\"><![CDATA[\n";
        $xml .= self::getEventList($DB, 1);
        $xml .= "]]>\n";
        $xml .= "  </replaceHTMLElement>\n";
        $xml .= "  <replaceHTMLElement id=\"table#inactiveEvents\"><![CDATA[\n";
        $xml .= self::getEventList($DB, 0);
        $xml .= "]]>\n";
        $xml .= "  </replaceHTMLElement>\n";
        $menu = new MainAdminUI($DB);
        $xml .= "  <replaceHTMLElement id=\"#menu_event_list\"><![CDATA[\n";
        $xml .= "    <li id=\"menu_event_list\" class=\"menutitem\">\n";
        $xml .= $menu->getEventSelectList($DB, "      ");
        $xml .= "    </li>\n";
        $xml .= "]]>\n";
        $xml .= "  </replaceHTMLElement>\n";
        break;
      default:
        $xml = parent::getPostBackXML($DB, $action);
    }
    return $xml;
  }
  
  public function doAction(DbConnection $DB, $action) {
    $id = "";
    switch ($action) {
      case "setActive":
        if($this->saveForm($DB)) {
          $id = $_POST['selected_id'];
        }
        break;
    }
    return $id;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // Database operations
  public function saveForm(DbConnection $DB) {
    if(preg_match("~^[0-9]+$~", $_POST['id'])) {
      $this->data = new Event(new FormValidation(array(), array()));
      list($errno, $error) = $this->data->readData($DB, array($this->data->getIDName()=>$_POST["id"]));
      if(!$errno) {
        list($errno, $error) = $this->data->setActive($DB);
        if ($errno) {
          $this->error = $error;
          return 0;
        }
        return 1;
      }
      else {
        $this->error = $error;
        return 0;
      }
    }
    
    $this->error = _("Validation failed.");
    return 0;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // output
  public function getHTML(DbConnection $DB) {
    if(isset($_SESSION['event']) && $_SESSION['event']->event_id) {
?>
<h3 class="first"><?=_("Statistics for event").' "'.$_SESSION['event']->event_title.'"'?></h3>
<?php
    echo "<p>Status: ".$_SESSION['event']->getStatus()."</p>\n\n";

    $bookings = UserBooking::getBookingsByOption($DB);
    echo "<h5>"._("Bookings")."</h5>\n";
    echo "<table class=\"padding alignleft\">\n";
    echo "<tr>\n";
    echo "  <th></th>\n";
    echo "  <th>"._("booked")."</th>\n";
    echo "  <th>"._("paid")."</th>\n";
    if($_SESSION['event']->enable_waitlist) echo "  <th>"._("waiting list")."</th>\n";
    echo "</tr>\n";
    foreach($bookings as $booking) {
      echo "<tr>\n";
      echo "  <td>{$booking['event_option']}:</td>\n";
      echo "  <td>{$booking['count']}</td>\n";
      echo "  <td>{$booking['count_paid']}</td>\n";
      if($_SESSION['event']->enable_waitlist) echo "  <td>{$booking['count_waitlisted']}</td>\n";
      echo "</tr>\n";
    }
    echo "</table>\n\n";

    $finances = UserBooking::getFinances($DB);
    echo "<h5>"._("Finance")."</h5>\n";
    echo "<table class=\"padding alignleft\">\n";
    echo "<tr>\n";
    echo "  <td>"._("Received payments").":</td>\n";
    echo "  <td style=\"text-align:right;\">{$finances['received']}</td>\n";
    echo "</tr>\n";
    echo "<tr>\n";
    echo "  <td>"._("Owing payments").":</td>\n";
    echo "  <td style=\"text-align:right;\">{$finances['owing']}</td>\n";
    echo "</tr>\n";
    echo "</table>\n\n";
?>

<h3><?=_("Links to user login and registration")?></h3>
<p><?=_("When creating links to the user login and registration pages of K_Db, use the following URLs to choose this event.")?></p>
<table class="padding alignleft">
<tr>
  <td valign="top"><?=_("User login")?>:</td>
  <td>http://<?=$_SERVER['SERVER_NAME'].preg_replace("~admin/index.php.*$~", "index.php?event_id={$_SESSION['event']->event_id}", $_SERVER['SCRIPT_NAME'])?></td>
</tr>
<tr>
  <td valign="top"><?=_("Registration")?>:</td>
  <td>http://<?=$_SERVER['SERVER_NAME'].preg_replace("~admin/index.php.*$~", "registration.php?event_id={$_SESSION['event']->event_id}",$_SERVER['SCRIPT_NAME'])?></td>
</tr>
</table>
<?php      
    }
?>
<h3<?=((isset($_SESSION['event']) && $_SESSION['event']->event_id) ? "" : " class=\"first\"")?>><?=_("K_Db sanity checks")?></h3>

<table class="padding alignleft">
<tr>
  <td><?=_("K_Db version")?>:</td>
  <td><?=KDB_VERSION?> (MySQL: <?=mysql_get_server_info()?>, PHP: <?=phpversion()?>)</td>
</tr>

<tr>
  <td><?=_("K_Db base path")?>:</td>
  <td><?=CWF_PATH?></td>
</tr>

<tr>
  <td><?=_("Directory 'upload' writable")?>:</td>
  <td><?=((is_writable(CWF_PATH."upload")) ? _("yes") : _("no"))?></td>
</tr>

<tr>
  <td><?=_("Login mode for admins")?>:</td>
  <td><?=CWFTools::getLoginModeStr(ADMIN_LOGIN_MODE)?></td>
</tr>
</table>

<h3><?=_("Events")?></h3>

<form id="kdb_form" action="" method="post" enctype="multipart/form-data">
<h5><?=_("Active events")?></h5>
<?php
    echo self::getEventList($DB, 1);
?>
<h5><?=_("Old events")?></h5>
<?php
    echo self::getEventList($DB, 0);
?>
</form>
<?php
  }
  
  static public function getEventList($DB, $active) {
    if($active) {
      $tableId = "activeEvents";
      $buttonTxt = _("Set inactive");
      $noEventsTxt = _("No active events.");
    }
    else {
      $tableId = "inactiveEvents";
      $buttonTxt = _("Set active");
      $noEventsTxt = _("No inactive events.");
    }
    $str = "<table id=\"{$tableId}\" class=\"padding\">\n";
    if ($events = Event::getList($DB, array("active"=>"{$active}"), $error)) {
      foreach ($events as $event) {
        $str .= "<tr>\n";
        $str .= "  <td>{$event->event_title}".($event->event_period ? " ({$event->event_period})" : "")."</td>\n";
        $str .= "  <td>{$event->getStatus()}</td>\n";
        if ($_SESSION['admin']['login']== "root" || !$event->db_admin_group_id || 
            in_array($event->db_admin_group_id, $_SESSION['admin']['db_admin_group_ids']))
          $str .= "  <td><input type=\"submit\" class=\"submit\" name=\"kdb_submit\" value=\"{$buttonTxt}\" onClick=\"kdbEventSetActive('KDbStatisticsUI', 'setActive', '{$event->event_id}'); return false;\"></td>\n";
        else
          $str .= "  <td><input type=\"submit\" class=\"submit\" name=\"kdb_submit\" value=\"{$buttonTxt}\" disabled></td>\n";
        $str .= "</tr>\n";
      }
    }
    else {
      $str .= "<tr><td>{$noEventsTxt}</td></tr>\n";
    }
    $str .= "</table>\n";
    return $str;
  }
}

?>