<?php
require_once("cwfUI.inc.php");
require_once("ViewDataUI.inc.php");

class ViewDeletedUI extends ViewDataUI {
  protected static $accessRight = "";
  protected static $dataClass = "";
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  public function __construct(DbConnection $DB) {
    $this->initialize($DB);
  }
  
  protected function initialize(DbConnection $DB) {
    $this->eventId = null;
    $this->columns = array();
    $this->view = new View();
    
    $this->view->columns = array("user_id", "familyname", "givenname", "email", "booked_program");
    $this->view->edit_booking_check = 0;
    $this->view->edit_user_data = 0;
    
    $this->showSelect = true;
    $this->showSelectAll = true;
    
    $this->title = _("View deleted records");
    
    $this->header = '  <script src="'.CWF_HTTP_PATH.'k_db/js/kdb_view.js" type="text/javascript"></script>'."\n";
    $this->header .= '  <link rel="stylesheet" href="'.CWF_HTTP_PATH.'k_db/css/view.css" type="text/css">';
    $this->header .= "  <script type=\"text/javascript\">
    var uiClassName = 'ViewDeletedUI';
    $(document).ready(function(){
      setupTableEvents(1);
      setupTableFixedHeader();
    });
  </script>\n";
    
    $this->sql = $this->getSQL($DB);
  }

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // handle data
  static public function getValidationRules($form=null) {
    $rules = array();
    $messages = array();
    
    $validationRules = new FormValidation($rules, $messages);
    return $validationRules;
  }
  
  public function isValid() {
    return true;
  }
  
  public function getPostBackXML(DbConnection $DB, $action) {
    $xml = parent::getPostBackXML($DB, $action);
    return $xml;
  }
  
  public function doAction(DbConnection $DB, $action) {
    $id = "";
    switch ($action) {
      case "updateForm":
      case "saveasnew":
      case "save":
        $id = parent::doAction($DB, $action, $_POST);
        break;
      case "delete":
        list($errno, $error) = $this->deleteData($DB, "");
        if ($errno>0)
          $errorMsg = _("Error")." {$errno}: {$error}";
        break;
    }
    return $id;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // Database operations
  public function saveForm(DbConnection $DB) {
    if(isset($_POST['select_booking_id'])) {
      $bookingIds = array_values($_POST['select_booking_id']);
      UserBooking::unDeleteData($DB, "booking_id IN ('".implode("', '", $bookingIds)."')");
    }
    if(isset($_POST['select_user_id'])) {
      $userIds = array_values($_POST['select_user_id']);
      User::unDeleteData($DB, "user_id IN ('".implode("', '", $userIds)."')");
    }
  }
  
  public function deleteData(DbConnection $DB, $id) {
    if($_SESSION['admin']['login']=="root") {
      if(isset($_POST['select_booking_id'])) {
        $bookingIds = array_values($_POST['select_booking_id']);
        UserBooking::deleteData($DB, "booking_id IN ('".implode("', '", $bookingIds)."')", 1);
      }
      if(isset($_POST['select_user_id'])) {
        $userIds = array_values($_POST['select_user_id']);
        User::deleteData($DB, "user_id IN ('".implode("', '", $userIds)."')", 1);
      }
    }
  }
  
  function getSQL(DbConnection $DB) {
    list($whereClause, $orderBy, $limit) = $this->prepareSQL($DB);
    
    $sql = "SELECT SQL_CALC_FOUND_ROWS ".implode(",\n       ", $this->getColumns("forSelect", true)).",\n".
           "  u.deleted,\n".
           "  ifnull(group_concat(ub.booking_id ORDER BY event_name SEPARATOR '<br>'), '') booking_id\n".
           "FROM users u\n".
           "  LEFT JOIN user_booking ub ON (ub.user_id=u.user_id)\n".
           "  LEFT JOIN events e ON (e.event_id=ub.event_id)\n".
           "WHERE (u.deleted=1 OR ub.deleted=1)\n".
           "GROUP BY u.user_id\n".
           (count($whereClause)>0 ? "HAVING ".implode("\n  AND ", $whereClause)."\n" : "").
           "ORDER BY {$orderBy} ".
           $limit.";";

    return $sql;
  }

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // output
  
  protected function getViewTableCell($column, $row) {
    $str = "";
    if($column['columnName']=="selectUser") {
      if($row['deleted'])
        $str .= "  <td style=\"white-space:nowrap;\">".
                "<input type=\"checkbox\" id=\"select_user_id_{$row['user_id']}\" name=\"select_user_id[{$row['user_id']}]\" value=\"{$row['user_id']}\"".
                ((isset($_POST['select_user_id'][$row['user_id']]) && $_POST['select_user_id'][$row['user_id']]) ? " checked" : "").
                ">";
      else
        $str .= "  <td style=\"white-space:nowrap;\"></td>";
    }
    else if($column['columnName']=="event") {
      if($row['event']) {
        $eventNames = explode("<br>", $row['event']);
        $bookingIds = explode("<br>", $row['booking_id']);
        $str .= "  <td style=\"white-space:nowrap;\">";
        foreach ($eventNames as $idx => $eventName)
          $str .= "<input type=\"checkbox\" id=\"select_booking_id_{$bookingIds[$idx]}\" name=\"select_booking_id[{$bookingIds[$idx]}]\" value=\"{$bookingIds[$idx]}\"".
                  ((isset($_POST['select_booking_id'][$bookingIds[$idx]]) && $_POST['select_booking_id'][$bookingIds[$idx]]) ? " checked" : "").
                  "> {$eventName}<br>";
        $str .= "</td>\n";
      }
      else
        $str .= "  <td style=\"white-space:nowrap;\"></td>";
    }
    else
      $str .= parent::getViewTableCell($column, $row);
    
    return $str;
  }
  
  public function getHTML(DbConnection $DB) {
?>
<form id="kdb_form_view" action="" method="post" enctype="multipart/form-data">

<div class="form_controls_top">
<p>
  <input type="submit" id="kdb_restore" name="kdb_restore" value="<?=_("Restore")?>" onClick="kdbSaveEntry('ViewDeletedUI', 'save', 'kdb_form_view'); return false;">
  <input type="submit" id="kdb_delete_selected" name="kdb_delete" value="<?=_("Delete")?>" onClick="kdbActionConfirmation('ViewDeletedUI', 'kdb_form_view', 'dialog_delete'); return false;">
</p>
</div>

<?php
    echo $this->getViewTable($DB);

    echo $this->resultPagination();
?>
<div id="dialog_delete" style="display:none;">
  <input type="submit" id="kdb_delete2" name="kdb_delete" value="<?=_("Really Delete")?>" onClick="kdbActionDo('ViewDeletedUI', 'kdb_form_view', 'dialog_delete'); return false;">
  <input type="submit" id="kdb_delete_cancel" name="kdb_delete_cancel" value="<?=_("Cancel")?>" onClick="kdbCancelAction('ViewDeletedUI', 'kdb_form_view', 'dialog_delete'); return false;">
</div>

<div class="form_controls_bottom">
<p>
  <input type="submit" id="kdb_restore2" name="kdb_restore" value="<?=_("Restore")?>" onClick="kdbSaveEntry('ViewDeletedUI', 'save', 'kdb_form_view'); return false;">
  <input type="submit" id="kdb_delete_selected2" name="kdb_delete" value="<?=_("Delete")?>" onClick="kdbActionConfirmation('ViewDeletedUI', 'kdb_form_view', 'dialog_delete'); return false;">
</p>
</div>
</form>

<span id="tt_filter" class="tooltip"><?= _("Wildcards:<br><u>*</u> any number of characters,<br><u>?</u> any single character.<br>Regular expressions must be enclosed in '/' (e.g. '/[a-z]+/').") ?></span>

<?php
  }
}

?>
