function throttle(f, delay){
  var timer = null;
  return function(){
    var context = this, args = arguments;
    clearTimeout(timer);
    timer = window.setTimeout(function(){
        f.apply(context, args);
    },
    delay || 500);
  };
}

jQuery.fn.single_double_click = function(single_click_callback, double_click_callback, timeout) {
  return this.each(function(){
    var clicks = 0, self = this;
    jQuery(this).click(function(event){
      clicks++;
      if (clicks == 1) {
        setTimeout(function(){
          if(clicks == 1) {
            single_click_callback.call(self, event);
          } else {
            double_click_callback.call(self, event);
          }
          clicks = 0;
        }, timeout || 300);
      }
    });
  });
};

function setupMenu(menuStyle, marginTop, marginBottom) {
  var callback = function () { return; };
  if (typeof(marginBottom)=="undefined") marginBottom=10;
  switch (menuStyle) {
    case 'vertical': 
      callback = function (currentMenu) {
          if ($('ul:first',currentMenu).length>0) {
            var submenu = $('ul:first',currentMenu);
            var offsetTop = submenu.parent().offset().top - $(document).scrollTop();
            if(submenu.height() > $(window).height()-marginTop-marginBottom) {
              if(submenu.css('column-count')!='auto' || submenu.css('column-width')!='auto')
                submenu.css('height', $(window).height()-marginTop-marginBottom)
                       .css('width', $('li:last', submenu).position().left-$('li:first', submenu).position().left+$('li:last', submenu).outerWidth());
              else
                submenu.css('height', $(window).height()-marginTop-marginBottom)
                       .css('overflow-y', 'scroll')
                       .css('overflow-x', 'hidden')
                       .css('width', 'auto');
            }
            if(offsetTop > $(window).height()-submenu.height()-marginBottom)
              submenu.css('top', $(window).height()-submenu.height()-offsetTop-marginBottom);
          }
        };
      break;
    case 'horizontal':
      break;
  }
  $("ul#dropdownmenu li").hoverIntent({ over: function(){
    $(this).addClass("hover");
    $('ul:first, div:first',this).fadeIn(300);
    callback($(this));
  }, timeout: 300, out: function(){
    $(this).removeClass("hover");
    $('ul:first, div:first',this).fadeOut(300);
  } });
}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Setup Tooltips
//
var overTooltip;

function getTooltipId(elementId) { 
  elementId = elementId.replace(/\[.*$/g, "");
  return "#tt_"+elementId.replace(/(:|\.)/g,'\\$1');    
}

function showTooltip(element) {
  $(".tooltip.visible").removeClass("visible").fadeOut(500);
  var tooltipItem = $(getTooltipId(element.attr("id")));
  var position = element.position();
  var width = tooltipItem.css('width');
  if(tooltipItem.attr("id")=="tt_filter") {
    position = element.offset();
    position.top += element.height()-$('div#menu').height() + 20;
    position.left += 5;
    width = 250;
  }
  else if(tooltipItem.attr("id")=="tt_limit") {
    var positionDiv = element.closest("div#pagination").offset();
    position.top += element.height()+15;
    position.left += 5;
    width = 250;
    if(element.width()+position.left+15+tooltipItem.width()+positionDiv.left>$("#menu").width())
      position.left = $("#menu").width() - (element.width()+15+tooltipItem.width()+positionDiv.left);
  }
  else if (tooltipItem.hasClass('below')) {
    position.top += element.height()+15;
    position.left += 5;
    width = 250;
  }
  else if(element.width()+position.left+15+tooltipItem.width()>$("#content").width()) {
    position.top += element.height()+15;
    position.left += 50;
  }
  else {
    position.top += 5;
    position.left += element.width()+15;
  }
  tooltipItem
    .css("top", position.top)
    .css("left", position.left)
    .css("width", width)
    .addClass("visible")
    .fadeIn(500);
}

function setupTooltips() {
  $("*[name], .with_tooltip").filter(function() {
    return ($(this).attr("id")!=undefined && $(getTooltipId($(this).attr("id"))).length>0 && !$(this).hasClass('persistant'));
  }).hoverIntent({ over: function() {
    showTooltip($(this)); 
  }, out: function() {
    $(getTooltipId($(this).attr("id"))).removeClass("visible").fadeOut(500);
  } });

  $("*[name].persistant, .with_tooltip.persistant").filter(function() {
    return ($(this).attr("id")!=undefined && $(getTooltipId($(this).attr("id"))).length>0);
  }).hoverIntent({ over: function() {
    showTooltip($(this));
  }, timeout: 1000, out: function() {
    if(!overTooltip)
      $(getTooltipId($(this).attr("id"))).removeClass("visible").fadeOut(500);
  } });

  $(".tooltip.persistant").hoverIntent(
    function() { overTooltip = 1; }, 
    function() { overTooltip = 0; $(this).removeClass("visible").fadeOut(500); }
  );
}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////
// AJAX Handler
//

function ajaxHandler(xml, formNode) {
  if(typeof(formNode)=="undefined") formNode = $('form');

  if($("newValues", xml).length>0) {
    $("newValues", xml).children().each(function(index) {
        nodeName = '*[id="'+$(this).attr("name")+'"]';
        if($('*[name="'+$(this).attr("name")+'[]"]').closest("div").hasClass("toggle_part")) {
          toggle = $('*[name="'+$(this).attr("name")+'[]"]').closest("div.toggle");
          $("div.toggle_selected li", toggle).each(function() {
            changeToggleElement($(this));
          });
          $(this).children("value").each(function() {
            if($(this).text().length>0)
              changeToggleElement($('*[value="'+$(this).text()+'"]', toggle).parent());
          });
        }
        else if($(nodeName).length==0) {
          radiobuttons = $('*[name="'+$(this).attr("name")+'"]');
          for (var i=0; i<radiobuttons.length; i++)
            radiobuttons[i].checked = (radiobuttons[i].value==$(this).text());
        }
        else {
          switch ($(nodeName).attr("type")) {
            case "checkbox":
              $(nodeName)[0].checked = (parseInt($(this).text())>0);
              break;
            case "radio":
              for (i=0; i<$(nodeName).length; i++)
                $(nodeName)[i].checked = ($(nodeName)[i].value==$(this).text());
              break;
            default:
              if($(this).children("value").length>0) {
                $(nodeName).val($(this).children("value").map(function() { return $(this).text(); }).get());
              }
              else
                $(nodeName).val($(this).text());
              break;
          }
        }
        $(nodeName).trigger('change');
      });
  }
  
  if($("activateButtons", xml).length>0) {
    $("activateButtons button", xml).each(function(i) {
      $("#"+$(this).text()).removeAttr("disabled");
    });
  }
  if($("deactivateButtons", xml).length>0) {
    $("deactivateButtons button", xml).each(function(i) {
      $("#"+$(this).text()).attr("disabled", "disabled");
    });
  }
  if($("selectList", xml).length>0) {
    $(".select_id option[value!=-1]").remove();
    $("selectList", xml).children().each(function(index) {
        $(".select_id").append('<option value="'+$(this).children("id").text()+'">'+$(this).children("name").text()+'</option>');
      });
    $(".select_id").val($("selectedEntry", xml).text());
  }
  if($("replaceHTMLElement", xml).length>0) {
    $("replaceHTMLElement", xml).each(function(index) {
        var id = $(this).attr("id");
        $(id).replaceWith($(this).text());
      });
  }
  if($("appendHTMLElement", xml).length>0) {
    $("appendHTMLElement", xml).each(function(index) {
        var id = $(this).attr("id");
        $(id).append($(this).text());
      });
  }
  if($("runFunction", xml).length>0) {
    $("runFunction", xml).each(function(index) {
        window[$(this).text()]();
      });
  }

  $("#error_message p").remove();
  if($("errorMessage", xml).length>0) {
    $("#error_message").append("<p>"+$("errorMessage", xml).text()+"</p>");
    $("#error_message").show();
  }
  else
    $("#error_message").hide();

  if($("notValid", xml).length>0) {
    var fields = [];
    $('notValid', xml).each(function() {
      fields.push('\"'+$(this).attr('name')+'\" : \"'+$(this).text()+'\"');
    });
    fields = '{'+fields.join(', ')+'}';
    fields = jQuery.parseJSON(fields);
    formNode.validate().showErrors(fields);
  }
  $("#ajax_message").slideUp(300);
  $("#ajax_message_container p").remove();  
}

function ajaxSendRequest(ajaxMessage, formNode, postValues, callback) {
  $("#ajax_message_container").append("<p>"+ajaxMessage+"</p>");
  $("#ajax_message").slideDown(300);
  $.post(CWF_HTTP_Path+ajaxHandlerScript, postValues, function(xml) { 
      ajaxHandler(xml, formNode);
      if(typeof(callback)!="undefined") callback();
    });
}

function cwfUpdateForm(formElement, className, formName, callback) {
  if(typeof(formName)=="undefined") formName = 'cwf_form';
  id = formElement.options[formElement.selectedIndex].value;
  ajaxSendRequest(ajaxLoadData, $('#'+formName), {"action": "updateForm", "id": id, "className": className, "formName": formName}, callback);
}

function cwfUpdateDialog(id, className, formName) {
  if(typeof(formName)=="undefined") formName = 'cwf_form';
  ajaxSendRequest(ajaxLoadData, $('#'+formName), {"action": "updateForm", "id": id, "className": className});
}

function cwfSaveEntry(className, action, formName, callback) {
  if(typeof(formName)=="undefined") formName = 'cwf_form';
  var formElement = $("#"+formName);
  if(!formElement.valid())
    return;
  if(action=="saveAsNew") $(".id").val("");
  ajaxSendRequest(ajaxSaveData, formElement, "action="+action+"&className="+className+"&formName="+formName+"&"+formElement.serialize(), callback);
}

function cwfDeleteEntry(className, formName, confirmationTxt, callback) {
  if(typeof(confirmationTxt)!="undefined" && !confirm(confirmationTxt)) return false;
  if(typeof(formName)=="undefined") formName = 'cwf_form';
  ajaxSendRequest(ajaxDeleteData, $('#'+formName), "action=delete&className="+className+"&"+$("#"+formName).serialize(), callback);
}
